@@ -2,23 +2,31 @@
 /* Many changes by Lars Bernhardsson. */
 /* Less changes by Florian Forster <octopus@verplant.org> */
 
-#define VERSION		"larswm 7.5.1 [21-JUN-2004] by Lars Bernhardsson <lab@fnurt.net>"
+#define VERSION		"larswm 7.5.3 [15-JUL-2004] by Lars Bernhardsson <lab@fnurt.net>"
 
 #define BORDER		2
 #define TILE_PAD	2
 
+#define L_OFF_R 32768
+#define L_OFF_G 32768
+#define L_OFF_B 32768
+
+#define L_ON_R 65535
+#define L_ON_G 0
+#define L_ON_B 0
+
+#define L_DELTA 16384
+
+#define L_TOP(x) (unsigned short) (((x) + L_DELTA) > 65535 ? 65535 : (x) + L_DELTA)
+#define L_BOT(x) (unsigned short) (((x) - L_DELTA) < 0 ? 0 : (x) - L_DELTA)
+
+#define BAR_HEIGHT	(2 + font->ascent + font->descent)
+#define BAR_TEXT_Y	(1 + font->ascent)
+
 #define BAR_X(s)	0
 #define BAR_Y(s)	(DisplayHeight (dpy, (s)->num) - BAR_HEIGHT)
 #define BAR_WIDTH(s)	(DisplayWidth (dpy, (s)->num))
 
-#ifdef THREE_D
-#define BAR_HEIGHT	(2 + font->ascent + font->descent)
-#define BAR_TEXT_Y	(1 + font->ascent)
-#else
-#define BAR_HEIGHT	(font->ascent + font->descent)
-#define BAR_TEXT_Y	(font->ascent)
-#endif
-
 #define DEFSHELL	"/bin/sh"
 
 #define DEFRC		"/etc/X11/larswmrc"
