@@ -10,6 +10,10 @@
 #include <errno.h>
 #include <time.h>
 
+#ifdef USE_LOCALE
+#include <locale.h>
+#endif
+
 #include <X11/X.h>
 #include <X11/Xos.h>
 #include <X11/Xlib.h>
@@ -30,6 +34,10 @@ main (int argc, char **argv)
   Atom bartext_larswm;
   XTextProperty pr;
 
+#ifdef USE_LOCALE
+  setlocale (LC_ALL, "");
+#endif
+
   for (i = 1; i < argc; i++)
     {
       if (strcmp (argv[i], "-display") == 0 && i + 1 < argc)
