@@ -124,6 +124,9 @@ static unsigned char nine_menu_bits[] = {
 #define CONFIG_MENU_SELECT_KEY  XK_Return
 #define CONFIG_MENU_CANCEL_KEY  XK_Escape
 
+#define PADX 100
+#define PADY 30
+
 char *progname;			/* my name */
 char *displayname;		/* X display */
 char *fontname;			/* font */
@@ -560,7 +563,7 @@ run_menu (void)
   dx = 0;
   for (i = 0; i < numitems; i++)
     {
-      wide = XTextWidth (font, labels[i], strlen (labels[i])) + 100;
+      wide = XTextWidth (font, labels[i], strlen (labels[i])) + PADX;
       if (wide > dx)
 	dx = wide;
     }
@@ -568,7 +571,7 @@ run_menu (void)
 
   old = cur = -1;
 
-  high = font->ascent + font->descent + 30;
+  high = font->ascent + font->descent + PADY;
   dy = numitems * high;
 
   set_wm_hints (wide, dy);
@@ -840,7 +843,7 @@ redraw (int cur, int high, int wide)
   for (i = 0; i < numitems; i++)
     {
       tx = (wide - XTextWidth (font, labels[i], strlen (labels[i]))) / 2;
-      ty = i * high + font->ascent + 15;
+      ty = i * high + font->ascent + (PADY / 2);
       XDrawString (dpy, menuwin, gc, tx, ty, labels[i], strlen (labels[i]));
     }
   if (cur >= 0 && cur < numitems)
