@@ -245,7 +245,6 @@ initscreen (ScreenInfo * s, int i)
     }
 
 #ifdef THREE_D
-#define MIN(x,y) (unsigned short) (x < y) ? x : y
   {
     XColor topcolor;
     XColor botcolor;
@@ -256,26 +255,30 @@ initscreen (ScreenInfo * s, int i)
     if ((get_c.pixel == WhitePixel (dpy, s->num)) ||
 	(get_c.pixel == BlackPixel (dpy, s->num)))
       {
-	topcolor.red = MIN (65535, (13 * 35000) / 10);
-	topcolor.green = MIN (65535, (13 * 35000) / 10);
-	topcolor.blue = MIN (65535, (13 * 35000) / 10);
-	botcolor.red = (7 * 35000) / 10;
-	botcolor.green = (7 * 35000) / 10;
-	botcolor.blue = (7 * 35000) / 10;
+        topcolor.red = L_TOP (L_OFF_R);
+        topcolor.green = L_TOP (L_OFF_G);
+        topcolor.blue = L_TOP (L_OFF_B);
+	
+        botcolor.red = L_BOT (L_OFF_R);
+        botcolor.green = L_BOT (L_OFF_G);
+        botcolor.blue = L_BOT (L_OFF_B);
       }
     else
       {
 	XQueryColor (dpy, s->def_cmap, &get_c);
-	topcolor.red = MIN (65535, (13 * get_c.red) / 10);
-	topcolor.green = MIN (65535, (13 * get_c.green) / 10);
-	topcolor.blue = MIN (65535, (13 * get_c.blue) / 10);
-	botcolor.red = (7 * get_c.red) / 10;
-	botcolor.green = (7 * get_c.green) / 10;
-	botcolor.blue = (7 * get_c.blue) / 10;
+
+	topcolor.red = L_TOP (get_c.red);
+	topcolor.green = L_TOP (get_c.green);
+	topcolor.blue = L_TOP (get_c.blue);
+
+	botcolor.red = L_BOT (get_c.red);
+	botcolor.green = L_BOT (get_c.green);
+	botcolor.blue = L_BOT (get_c.blue);
       }
 
     XAllocColor (dpy, s->def_cmap, &topcolor);
     XAllocColor (dpy, s->def_cmap, &botcolor);
+
     s->topwhite = topcolor.pixel;
     s->botwhite = botcolor.pixel;
 
@@ -294,26 +297,30 @@ initscreen (ScreenInfo * s, int i)
     if ((get_c.pixel == WhitePixel (dpy, s->num)) ||
 	(get_c.pixel == BlackPixel (dpy, s->num)))
       {
-	topcolor.red = MIN (65535, (13 * 50000) / 10);
-	topcolor.green = MIN (65535, (13 * 20000) / 10);
-	topcolor.blue = MIN (65535, (13 * 20000) / 10);
-	botcolor.red = (7 * 50000) / 10;
-	botcolor.green = (7 * 20000) / 10;
-	botcolor.blue = (7 * 20000) / 10;
+        topcolor.red = L_TOP (L_ON_R);
+        topcolor.green = L_TOP (L_ON_G);
+        topcolor.blue = L_TOP (L_ON_B);
+
+	botcolor.red = L_BOT (L_ON_R);
+        botcolor.green = L_BOT (L_ON_G);
+        botcolor.blue = L_BOT (L_ON_B);
       }
     else
       {
 	XQueryColor (dpy, s->def_cmap, &get_c);
-	topcolor.red = MIN (65535, (13 * get_c.red) / 10);
-	topcolor.green = MIN (65535, (13 * get_c.green) / 10);
-	topcolor.blue = MIN (65535, (13 * get_c.blue) / 10);
-	botcolor.red = (7 * get_c.red) / 10;
-	botcolor.green = (7 * get_c.green) / 10;
-	botcolor.blue = (7 * get_c.blue) / 10;
+	
+	topcolor.red = L_TOP (get_c.red);
+	topcolor.green = L_TOP (get_c.green);
+	topcolor.blue = L_TOP (get_c.blue);
+	
+	botcolor.red = L_BOT (get_c.red);
+	botcolor.green = L_BOT (get_c.green);
+	botcolor.blue = L_BOT (get_c.blue);
       }
-
+    
     XAllocColor (dpy, s->def_cmap, &topcolor);
     XAllocColor (dpy, s->def_cmap, &botcolor);
+
     s->topblack = topcolor.pixel;
     s->botblack = botcolor.pixel;
 
@@ -327,7 +334,6 @@ initscreen (ScreenInfo * s, int i)
     mask = GCForeground | GCLineWidth;
     s->botblackgc = XCreateGC (dpy, s->root, mask, &gv);
   }
-#undef MIN
 #endif
 
   gv.foreground = s->black ^ s->white;
